# big\_g

## Installing the PyPI package

The ``big-g`` package is available on PyPI.

    pip install big-g

Installing via ``pip`` should get most of the Python dependencies you need.
OpenCV installation can sometimes be tricky, so this may need to be installed
manually before big\_g will operate correctly.

## Object Tracking

To run the big\_g program, simply run:

    big-g-tracking

Help can be found by running `big-g-tracking --help`.
